JsonError

Enum JsonError 

pub enum JsonError {
    Empty,
    InvalidChar(char, usize),
    UnterminatedString,
    EndedOnEscape,
    UnknownEscapeSequence(char),
    NonStringAsKey,
    InvalidCodepoint,
    InvalidNumber,
}
An error that occured while parsing a json file

The reading functions work recursive, that means major errors might end up in the wrong category, for example mismatched parantheses result in an Empty error:

 assert_eq!(JsonObject::read("[[[]]"), Err(Empty));

Variants



Empty

The input was empty (or only whitespace)



InvalidChar(char, usize)

At the given position the given character was read invalidly



UnterminatedString

A string with no closing quote



EndedOnEscape

The input ended on a backslash



UnknownEscapeSequence(char)

An unknown escape sequence was encountered



NonStringAsKey

A not string was used as key in an JsonObject::Obj



InvalidCodepoint

Per ‘\uXXXX’ was an invalid code point specified



InvalidNumber

A number that is invalid in json, but is a perfectly fine floating-point number.